//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

using LidorSystems.IntegralUI.Containers;
using LidorSystems.IntegralUI.Drawing;

namespace Multi_Color_Tabs
{
    public partial class Form1 : Form
    {
        #region Variables
        private const String referencePath = "../../../Demo/";
        #endregion

        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitPages();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>In this sample we are showing how to create tabs with different colors.</p><br></br>";
            content += "<p>Each tab has its own set of color styles which allows you to change their appearance. Depending on current state of tab page, whether it is disabled, hovered, focused, selected or just normal state, a corresponding color style is used. Check out the source code for more information.</p><br></br>";
            content += "<p>When you click on 'Add Page' button a new tab page will be created in different color.</p><br></br>";
            content += "<p>In this example we are also adding a Label 'My Notebook', showed to the left side of tabs, which is done by using a toolbar containing only non-selectable label with image.</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr height=\"5\"></tr>";
            content += "<tr><td width=\"70%\" style=\"textcolor:DarkRed;hovertextcolor:Red\"><a href=\"QuickStart.exe\" id=\"FILE\">Quick Start</a></td>";
            content += "<td width=\"30%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/tabcontrol/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
            {
                String relativePath = (e.Object as LinkLabel).Links[0].LinkData.ToString();

                if (e.Key == "FILE")
                {
                    String appPath = Path.GetFullPath(Path.Combine(referencePath, relativePath));
                    if (File.Exists(appPath))
                        System.Diagnostics.Process.Start(appPath);
                    else if (File.Exists(relativePath))
                        System.Diagnostics.Process.Start(relativePath);
                }
                else
                    System.Diagnostics.Process.Start(relativePath);

            }
        }

        private void InitPages()
        {
            this.tabControl1.TabShape = TabShape.TrapezoidalRight;
            this.tabControl1.TabSpacing = 15;
            this.tabControl1.NormalTabStripButtonStyle.ForeColor = Color.White;
            //this.tabControl1.HoverTabStripButtonStyle.ForeColor = Color.Black;


            this.tabControl1.TabStripStyle.BackFadeColor = Color.SteelBlue;
            this.tabControl1.ToolItemFormatStyle.Font = new Font(Control.DefaultFont, FontStyle.Bold);
            this.tabControl1.NormalToolItemStyle.TextColor = Color.White;
            this.tabControl1.HoverToolItemStyle.BackColor = Color.Transparent;
            this.tabControl1.HoverToolItemStyle.BackFadeColor = Color.Transparent;
            this.tabControl1.HoverToolItemStyle.BorderColor = Color.Transparent;
            this.tabControl1.HoverToolItemStyle.TextColor = Color.White;

            LidorSystems.IntegralUI.Controls.ToolLabel tLabel = new LidorSystems.IntegralUI.Controls.ToolLabel();
            tLabel.Text = " My Notebook";
            tLabel.ImageIndex = 0;
            this.tabControl1.ToolBar.Add(tLabel);

            for (int i = 1; i <= 3; i++)
                AddPage(i);
        }
        #endregion

        #region Functionality
        private void btnAdd_Click(object sender, EventArgs e)
        {
            int colorIndex = (this.tabControl1.Pages.Count + 1) % 7;
            AddPage(colorIndex);
        }

        private void AddPage(int index)
        {
            LidorSystems.IntegralUI.Containers.TabPage page = new LidorSystems.IntegralUI.Containers.TabPage();
            int tabIndex = this.tabControl1.Pages.Count + 1;
            page.Text = "TabPage " + tabIndex.ToString();

            // Make sure tab page not uses the settings from its parent TabControl
            page.StyleFromParent = false;
            page.FormatStyle.Padding = new Padding(5);
            page.NormalStyle.BackFadeColor = Color.White;
            page.HoverStyle.BackFadeColor = Color.White;

            switch (index)
            {
                case 1:
                    page.NormalStyle.BackColor = Color.Red;
                    page.NormalStyle.BorderColor = Color.DarkRed;
                    break;
                case 2:
                    page.NormalStyle.BackColor = Color.Yellow;
                    page.NormalStyle.BorderColor = Color.Black;
                    break;
                case 3:
                    page.NormalStyle.BackColor = Color.Green;
                    page.NormalStyle.BorderColor = Color.DarkGreen;
                    break;
                case 4:
                    page.NormalStyle.BackColor = Color.SteelBlue;
                    page.NormalStyle.BorderColor = Color.DarkBlue;
                    break;
                case 5:
                    page.NormalStyle.BackColor = Color.Violet;
                    page.NormalStyle.BorderColor = Color.DarkViolet;
                    break;
                case 6:
                    page.NormalStyle.BackColor = Color.Brown;
                    page.NormalStyle.BorderColor = Color.SaddleBrown;
                    break;
            }

            page.HoverStyle.BackColor = CommonMethods.ChangeColor(page.NormalStyle.BackColor, 35, true);

            this.tabControl1.Pages.Add(page);
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            if (this.tabControl1.SelectedPage != null)
                this.tabControl1.SelectedPage.Remove();
        }
        #endregion
    }
}