'                                                                  
' Copyright  2013 Lidor Systems.
' All Rights Reserved.
'
' This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
' either express or implied.                        
'

Imports System.IO
Imports LidorSystems.IntegralUI.Containers
Imports LidorSystems.IntegralUI.Drawing

Public Class Form1

#Region "Variables"
    Private Const referencePath As [String] = "../../../Demo/"
#End Region

#Region "Initialization"
    Public Sub New()
        InitializeComponent()

        CreateLabelContent()

        InitPages()
    End Sub

    Private Sub CreateLabelContent()
        Dim content As [String] = "<div style=""font:Verdana,9,r""><p>In this sample we are showing how to create tabs with different colors.</p><br></br>"
        content += "<p>Each tab has its own set of color styles which allows you to change their appearance. Depending on current state of tab page, whether it is disabled, hovered, focused, selected or just normal state, a corresponding color style is used. Check out the source code for more information.</p><br></br>"
        content += "<p>When you click on 'Add Page' button a new tab page will be created in different color.</p><br></br>"
        content += "<p>In this example we are also adding a Label 'My Notebook', showed to the left side of tabs, which is done by using a toolbar containing only non-selectable label with image.</p><br></br>"
        content += "<p><table width=""100%"" cellpadding=""5""><tr height=""5""></tr>"
        content += "<tr><td width=""70%"" style=""textcolor:DarkRed;hovertextcolor:Red""><a href=""QuickStart.exe"" id=""FILE"">Quick Start</a></td>"
        content += "<td width=""30%"" style=""align:middleright;textcolor:DarkRed;hovertextcolor:Red""><a href=""www.lidorsystems.com/support/articles/winforms/tabcontrol/"">More Info ...</a></td></tr></table></p>"
        content += "</div>"

        Me.labelInfo.Content = content
    End Sub

    Private Sub labelInfo_ContentObjectClicked(ByVal sender As Object, ByVal e As LidorSystems.IntegralUI.ObjectClickEventArgs) Handles labelInfo.ContentObjectClicked
        If TypeOf e.[Object] Is LinkLabel Then
            Dim relativePath As [String] = TryCast(e.[Object], LinkLabel).Links(0).LinkData.ToString()

            If e.Key = "FILE" Then
                Dim appPath As [String] = Path.GetFullPath(Path.Combine(referencePath, relativePath))
                If File.Exists(appPath) Then
                    System.Diagnostics.Process.Start(appPath)
                ElseIf File.Exists(relativePath) Then
                    System.Diagnostics.Process.Start(relativePath)
                End If
            Else
                System.Diagnostics.Process.Start(relativePath)

            End If
        End If
    End Sub

    Private Sub InitPages()
        Me.tabControl1.TabShape = TabShape.TrapezoidalRight
        Me.tabControl1.TabSpacing = 15
        Me.tabControl1.NormalTabStripButtonStyle.ForeColor = Color.White

        Me.tabControl1.TabStripStyle.BackFadeColor = Color.SteelBlue
        Me.tabControl1.ToolItemFormatStyle.Font = New Font(Control.DefaultFont, FontStyle.Bold)
        Me.tabControl1.NormalToolItemStyle.TextColor = Color.White
        Me.tabControl1.HoverToolItemStyle.BackColor = Color.Transparent
        Me.tabControl1.HoverToolItemStyle.BackFadeColor = Color.Transparent
        Me.tabControl1.HoverToolItemStyle.BorderColor = Color.Transparent
        Me.tabControl1.HoverToolItemStyle.TextColor = Color.White

        Dim tLabel As New LidorSystems.IntegralUI.Controls.ToolLabel()
        tLabel.Text = " My Notebook"
        tLabel.ImageIndex = 0
        Me.tabControl1.ToolBar.Add(tLabel)

        For i As Integer = 1 To 3
            AddPage(i)
        Next
    End Sub
#End Region

#Region "Functionality"
    Private Sub btnAdd_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnAdd.Click
        Dim colorIndex As Integer = (Me.tabControl1.Pages.Count + 1) Mod 7
        AddPage(colorIndex)
    End Sub

    Private Sub AddPage(ByVal index As Integer)
        Dim page As New LidorSystems.IntegralUI.Containers.TabPage()
        Dim tabIndex As Integer = Me.tabControl1.Pages.Count + 1
        page.Text = "TabPage " & tabIndex.ToString()
        page.StyleFromParent = False
        page.FormatStyle.Padding = New Padding(5)
        page.NormalStyle.BackFadeColor = Color.White
        page.HoverStyle.BackFadeColor = Color.White

        Select Case index
            Case 1
                page.NormalStyle.BackColor = Color.Red
                page.NormalStyle.BorderColor = Color.DarkRed
                Exit Select
            Case 2
                page.NormalStyle.BackColor = Color.Yellow
                page.NormalStyle.BorderColor = Color.Black
                Exit Select
            Case 3
                page.NormalStyle.BackColor = Color.Green
                page.NormalStyle.BorderColor = Color.DarkGreen
                Exit Select
            Case 4
                page.NormalStyle.BackColor = Color.SteelBlue
                page.NormalStyle.BorderColor = Color.DarkBlue
                Exit Select
            Case 5
                page.NormalStyle.BackColor = Color.Violet
                page.NormalStyle.BorderColor = Color.DarkViolet
                Exit Select
            Case 6
                page.NormalStyle.BackColor = Color.Brown
                page.NormalStyle.BorderColor = Color.SaddleBrown
                Exit Select
        End Select

        page.HoverStyle.BackColor = CommonMethods.ChangeColor(page.NormalStyle.BackColor, 35, True)

        Me.tabControl1.Pages.Add(page)
    End Sub

    Private Sub btnRemove_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnRemove.Click
        If Me.tabControl1.SelectedPage IsNot Nothing Then
            Me.tabControl1.SelectedPage.Remove()
        End If
    End Sub
#End Region

End Class
